@@ -1,4 +1,4 @@
-library(symbolicDA) 
+require(symbolicDA)
 data("cars",package="symbolicDA")
 set.seed(123)
 w<-replication.SDA(cars, u=3, method="SClust", S=10)
